==> ghdl_2.0.0+dfsg.orig.tar.xz: ghdl-2.0.0/pyGHDL/libghdl/vhdl/utils.py <==
# =============================================================================
#               ____ _   _ ____  _       _ _ _           _         _ _
#  _ __  _   _ / ___| | | |  _ \| |     | (_) |__   __ _| |__   __| | |
# | '_ \| | | | |  _| |_| | | | | |     | | | '_ \ / _` | '_ \ / _` | |
# | |_) | |_| | |_| |  _  | |_| | |___ _| | | |_) | (_| | | | | (_| | |
# | .__/ \__, |\____|_| |_|____/|_____(_)_|_|_.__/ \__, |_| |_|\__,_|_|
# |_|    |___/                                     |___/
# =============================================================================
# Authors:
#   Tristan Gingold
#   Patrick Lehmann
#
# Package module:   Python binding and low-level API for shared library 'libghdl'.
#
# License:
# ============================================================================
#  Copyright (C) 2019-2021 Tristan Gingold
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <gnu.org/licenses>.
#
# SPDX-License-Identifier: GPL-2.0-or-later
# ============================================================================

from pyTooling.Decorators import export

from pyGHDL.libghdl._types import Iir, NameId
from pyGHDL.libghdl._decorator import BindToLibGHDL


@export
@BindToLibGHDL("vhdl__utils__get_source_identifier")
def Get_Source_Identifier(Decl: Iir) -> NameId:
    """
    Like ``Get_Identifier`` but return a ``NameId`` for the same casing as it appears in the source file.
    Not useful for analysis as VHDL is case insensitive, but could be useful for error messages or tooling.

    :param Decl: Iir Node. Type: ``Iir``
    """
    return 0

==> ghdl_5.0.1+dfsg.orig.tar.xz: ghdl-5.0.1/pyGHDL/libghdl/vhdl/utils.py <==
# =============================================================================
#               ____ _   _ ____  _       _ _ _           _         _ _
#  _ __  _   _ / ___| | | |  _ \| |     | (_) |__   __ _| |__   __| | |
# | '_ \| | | | |  _| |_| | | | | |     | | | '_ \ / _` | '_ \ / _` | |
# | |_) | |_| | |_| |  _  | |_| | |___ _| | | |_) | (_| | | | | (_| | |
# | .__/ \__, |\____|_| |_|____/|_____(_)_|_|_.__/ \__, |_| |_|\__,_|_|
# |_|    |___/                                     |___/
# =============================================================================
# Authors:
#   Tristan Gingold
#   Patrick Lehmann
#
# Package module:   Python binding and low-level API for shared library 'libghdl'.
#
# License:
# ============================================================================
#  Copyright (C) 2019-2021 Tristan Gingold
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <gnu.org/licenses>.
#
# SPDX-License-Identifier: GPL-2.0-or-later
# ============================================================================

from pyTooling.Decorators import export

from pyGHDL.libghdl._types import Iir, NameId
from pyGHDL.libghdl._decorator import BindToLibGHDL
from pyGHDL.libghdl import name_table, files_map
from pyGHDL.libghdl.vhdl import nodes


@export
@BindToLibGHDL("vhdl__utils__get_source_identifier")
def Get_Source_Identifier(Decl: Iir) -> NameId:
    """
    Like ``Get_Identifier`` but return a ``NameId`` for the same casing as it appears in the source file.
    Not useful for analysis as VHDL is case insensitive, but could be useful for error messages or tooling.

    :param Decl: Iir Node. Type: ``Iir``
    """
    return 0


@export
def Get_Source_Identifier_Str(n: Iir) -> str:
    loc = nodes.Get_Location(n)
    l = name_table.Get_Name_Length(nodes.Get_Identifier(n))
    sfe = files_map.Location_To_File(loc)
    pos = files_map.Location_File_To_Pos(loc, sfe)
    buf = files_map.Get_File_Buffer(sfe)
    return buf[pos : pos + l].decode("utf-8")
